#include <iostream>
#include <opencv2/opencv.hpp>
#include <opencv2/imgproc/imgproc.hpp>
#include <opencv2/highgui/highgui.hpp>

using namespace cv;

cv::Mat 
my_grayscale_conversion(const cv::Mat& color)
{
  /* fill your implementation */
  cv::Mat gray (color.rows, color.cols, CV_8UC1);
  for (size_t r = 0; r < gray.rows; ++r)
  {
      for (size_t c = 0; c < gray.cols; ++c)
      {
          Vec3b bgr = color.at<Vec3b>(r, c);
          gray.at<uchar>(r, c) = static_cast<uchar>(bgr[2] * 0.299 + bgr[1] * 0.587 + bgr[0] * 0.114);
      }
  }


  return gray;
}

int
main ()
{
  Mat image = imread("bird.jpg", IMREAD_COLOR);    // Load
  
  /* Here fill in your implementation to convert to grayscale image. 
   * Note that openCV read image in BGR order. */
  Mat mygray = my_grayscale_conversion(image);
  
  Mat refgray;
  cvtColor(image, refgray, COLOR_BGR2GRAY);       // Build-in function
  
  namedWindow("img", CV_WINDOW_AUTOSIZE);
  namedWindow("mygray", CV_WINDOW_AUTOSIZE);
  namedWindow("refgray", CV_WINDOW_AUTOSIZE);
  imshow("img", image);                           // Load
  imshow("mygray", mygray);
  imshow("refgray", refgray);
  waitKey(0);

  imwrite("grayscale.png", refgray);              // Save 
 
  return 0;
}
